@@ -1,4 +1,5 @@
 import asyncio
+import enum
 import threading
 import typing
 import weakref
@@ -19,6 +20,11 @@ class AlreadyStarted(Exception):
     pass
 
 
+class DataWhen(enum.IntEnum):
+    Always = _native.DATA_REQUEST_FLAG.DEFAULT
+    WhenChanged = _native.DATA_REQUEST_FLAG.CHANGED
+
+
 class Sim:
 
     OPEN_TIMEOUT_SEC: float = 5
@@ -140,7 +146,9 @@ class Sim:
         request = self.request_data_on_sim_object(fields, PERIOD.ONCE, object_id)
         return await request.wait(timeout)
 
-    def request_data_on_sim_object(self, fields: typing.List[DataField], period: PERIOD, object_id: int = 0):
+    def request_data_on_sim_object(
+            self, fields: typing.List[DataField], period: PERIOD, object_id: int = 0, when: DataWhen = DataWhen.Always,
+            origin: int = 0, interval: int = 0, limit: int = 0):
         # TODO: Add explicit unsubscribe
         definition_id = self._definition_id_inc.next(self._data_definition_ids)
         request_id = self._data_request_id_inc.next(self._data_requests)
@@ -158,7 +166,16 @@ class Sim:
             for field in fields:
                 self.sim.add_to_data_definition(definition_id, field.name, field.units, field.type.data_type)
                 packet_ids.append(self.sim.get_last_sent_packet_id())
-            self.sim.request_data_on_sim_object(request_id, definition_id, object_id, period)
+            self.sim.request_data_on_sim_object(
+                request_id,
+                definition_id,
+                object_id,
+                period,
+                when,
+                origin,
+                interval,
+                limit,
+            )
             data_request = DataRequest(
                 packet_ids=packet_ids,
                 fields=fields,
